@@ -27,9 +27,7 @@
 #include <QDate>
 #include <QGraphicsItem>
 
-namespace EventViews
-{
-
+namespace EventViews {
 class MonthItem;
 
 /**
@@ -46,10 +44,10 @@ public:
 
     explicit ScrollIndicator(ArrowDirection direction);
 
-    QRectF boundingRect() const override;
+    Q_REQUIRED_RESULT QRectF boundingRect() const override;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
 
-    ArrowDirection direction() const
+    Q_REQUIRED_RESULT ArrowDirection direction() const
     {
         return mDirection;
     }
@@ -85,6 +83,7 @@ public:
     {
         return mId;
     }
+
     QDate date() const
     {
         return mDate;
@@ -109,6 +108,7 @@ public:
     {
         return mUpArrow;
     }
+
     ScrollIndicator *downArrow() const
     {
         return mDownArrow;
@@ -118,10 +118,10 @@ private:
     int mId;
     QDate mDate;
 
-    QGraphicsScene *mScene;
+    QGraphicsScene *mScene = nullptr;
 
-    ScrollIndicator *mUpArrow;
-    ScrollIndicator *mDownArrow;
+    ScrollIndicator *mUpArrow = nullptr;
+    ScrollIndicator *mDownArrow = nullptr;
 };
 
 /**
@@ -216,9 +216,8 @@ private:
     int mDaySpan;
 
     // The current item is part of a MonthItem
-    MonthItem *mMonthItem;
+    MonthItem *mMonthItem = nullptr;
 };
-
 }
 
 #endif
